@@ -1,5 +1,5 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.0.5.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+/* readinputfile.h -- This file is part of Archimedes release 0.0.7.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
@@ -25,13 +25,13 @@
 
 // ######################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 07 apr.2005, Siracusa, J.M.Sellier
+// Last modif. : 27 dec.2006, Siracusa, J.M.Sellier
 // ######################################################
 
 // Read the geometrical and physical description of the device.
 // The input file is interpreted as in a script language.
 // For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.0.5
+// the manual GNU Archimedes release 0.0.7
 
 void
 Read_Input_File(void)
@@ -111,6 +111,14 @@ Processing the input file\n\
       msh=mstarHGAAS;
       printf("MATERIAL %s ---> Ok\n",s);
     }
+    else if(strcmp(s,"GERMANIUM")==0){
+      Material==GERMANIUM;
+      epsMATERIAL=EPSR_Ge*EPS0;
+      alphaMATERIAL=alphaGERMANIUM;
+      mstar=mstarGERMANIUM;
+      msh=mstarHGERMANIUM;
+      printf("MATERIAL %s ---> Ok\n",s);
+    }
 // if the material specified does not exist then exit
     else{
       printf("%s: unknow specified material\n",progname);
